# Fix misspellings in comments.
authorPaul Eggert <eggert@gnu.org>
Sun, 10 Jan 1993 22:33:45 +0000 (22:33 +0000)
committerPaul Eggert <eggert@gnu.org>
Sun, 10 Jan 1993 22:33:45 +0000 (22:33 +0000)
From-SVN: r3182

gcc/gcc.c
gcc/libgcc2.c

index ff13c10592e5d73c24051b880fe0bf81b09bf58d..79be0499a630e3a9e0748fea2239fdac19db68aa 100644 (file)
--- a/gcc/gcc.c
+++ b/gcc/gcc.c
@@ -2204,7 +2204,7 @@ process_command (argc, argv)
       else if (argv[i][0] == '+' && argv[i][1] == 'e')
        {
          /* Compensate for the +e options to the C++ front-end;
-            they're there simply for cfront call-compatability.  We do
+            they're there simply for cfront call-compatibility.  We do
             some magic in default_compilers to pass them down properly.
             Note we deliberately start at the `+' here, to avoid passing
             -e0 or -e1 down into the linker.  */
index 42cc2fbf2f08bf17eea8ace88be288b5f68edd30..efd1edb21c6fb43ce65e98efda1a88a3ec54c693 100644 (file)
@@ -62,10 +62,10 @@ typedef             float XFtype    __attribute__ ((mode (XF)));
 typedef                float TFtype    __attribute__ ((mode (TF)));
 #endif
 
/* Make sure that we don't accidentaly use any normal C language built-in
    type names in the first part of this file.  Instead we want to use *only*
    the type names defined above.  The following macro definitions insure
-   that if we *do* accidently use soem normal C language built-in type name,
+   that if we *do* accidentally use soem normal C language built-in type name,
    we will get a syntax error.  */
 
 #define char bogus_type
@@ -62,10 +62,10 @@ typedef             float XFtype    __attribute__ ((mode (XF)));
 #endif
 
-/* Make sure that we don't accidentaly use any normal C language built-in
+/* Make sure that we don't accidentally use any normal C language built-in
    type names in the first part of this file.  Instead we want to use *only*
    the type names defined above.  The following macro definitions insure